@@ -1,12 +1,12 @@
 # pparse.rb
-#   $Id: pparse.rb,v 1.5 2000/11/12 00:37:33 keiko Exp $
+#   $Id: pparse.rb,v 1.1.1.1 2011-02-23 07:21:28 horinout Exp $
 
 
-require "prototype"
+require "./prototype"
 
 class PrototypeParser
   def parse(&block)
-    @cpp.each do |line|
+    @cpp.each_line do |line|
       case line
       when /^\s*$/
 	next
